@@ -75,6 +75,10 @@ sub ccflags {
 	push @ccflags, '-DUTF_8_PLAIN_TEXT';
     }
 
+    # Darwin 21 = macOS 12 = Monterey
+    $darwin_version >= 21
+	and push @ccflags, '-DMACOS_MONTEREY';
+
     $opt->{p}
 	and push @ccflags, qw{ -DUSE_PBL_BACKEND };
 
@@ -82,10 +86,6 @@ sub ccflags {
     $?
 	or push @ccflags, '-DUSE_MACTYPES';
 
-    system "$Config{cc} -Werror -Wno-compound-token-split-by-macro -o /dev/null inc/true.c 2>/dev/null";
-    $?
-	or push @ccflags, '-Wno-compound-token-split-by-macro';
-
     if ( my $debug = $ENV{DEVELOPER_DEBUG} ) {
 	push @ccflags, '-DDEBUG_PBL';
 	$debug =~ m/ \b backtrace \b /smxi
@@ -468,7 +468,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2022 by Thomas R. Wyant, III
+Copyright (C) 2010-2023 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
